Script 'mail_helper' called by obssrc
Hello community,

here is the log from the commit of package python-jedi for openSUSE:Factory 
checked in at 2023-10-17 20:22:33
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/python-jedi (Old)
 and      /work/SRC/openSUSE:Factory/.python-jedi.new.20540 (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "python-jedi"

Tue Oct 17 20:22:33 2023 rev:40 rq:1118190 version:0.19.1

Changes:
--------
--- /work/SRC/openSUSE:Factory/python-jedi/python-jedi.changes  2023-08-11 
15:55:39.695808591 +0200
+++ /work/SRC/openSUSE:Factory/.python-jedi.new.20540/python-jedi.changes       
2023-10-17 20:22:39.858379573 +0200
@@ -1,0 +2,7 @@
+Tue Oct 17 05:23:31 UTC 2023 - Steve Kowalik <steven.kowa...@suse.com>
+
+- Update to 0.19.1:
+  * Python 3.12 support
+- Stop skipping some tests.
+
+-------------------------------------------------------------------

Old:
----
  jedi-0.19.0.tar.gz

New:
----
  jedi-0.19.1.tar.gz

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ python-jedi.spec ++++++
--- /var/tmp/diff_new_pack.lcVzXA/_old  2023-10-17 20:22:40.750410800 +0200
+++ /var/tmp/diff_new_pack.lcVzXA/_new  2023-10-17 20:22:40.750410800 +0200
@@ -16,14 +16,12 @@
 #
 
 
-%define skip_python2 1
 %{?sle15_python_module_pythons}
 Name:           python-jedi
-Version:        0.19.0
+Version:        0.19.1
 Release:        0
 Summary:        An autocompletion tool for Python
 License:        MIT AND Python-2.0
-Group:          Development/Languages/Python
 URL:            https://github.com/davidhalter/jedi
 Source0:        
https://files.pythonhosted.org/packages/source/j/jedi/jedi-%{version}.tar.gz
 Source1:        %{name}-rpmlintrc
@@ -72,20 +70,13 @@
 skiptests+=" or test_speed"
 # fails on some architectures
 skiptests+=" or test_init_extension_module"
-# https://github.com/davidhalter/jedi/issues/1824
-skiptests+=" or (test_completion and lambdas and 112)"
-# https://github.com/davidhalter/jedi/issues/1846
-skiptests+=" or (test_completion and conftest and 27)"
-skiptests+=" or (test_completion and pytest and 142)"
 # This fails on 15.4_py39 server-side but not locally (!?)
 skiptests+=" or test_get_default_environment_when_embedded"
-# https://github.com/davidhalter/jedi/issues/1929
-skiptests+=" or test_attrs_signature"
 %pytest -k "not ($skiptests)"
 
 %files %{python_files}
 %doc AUTHORS.txt CHANGELOG.rst README.rst
 %license LICENSE.txt
-%{python_sitelib}/jedi-%{version}*-info
 %{python_sitelib}/jedi
+%{python_sitelib}/jedi-%{version}.dist-info
 

++++++ jedi-0.19.0.tar.gz -> jedi-0.19.1.tar.gz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/CHANGELOG.rst 
new/jedi-0.19.1/CHANGELOG.rst
--- old/jedi-0.19.0/CHANGELOG.rst       2023-07-29 00:59:28.000000000 +0200
+++ new/jedi-0.19.1/CHANGELOG.rst       2023-10-02 11:17:54.000000000 +0200
@@ -6,6 +6,11 @@
 Unreleased
 ++++++++++
 
+0.19.1 (2023-10-02)
++++++++++++++++++++
+
+- Python 3.12 support (Thanks Peter!)
+
 0.19.0 (2023-07-29)
 +++++++++++++++++++
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/PKG-INFO new/jedi-0.19.1/PKG-INFO
--- old/jedi-0.19.0/PKG-INFO    2023-07-29 01:05:44.501212400 +0200
+++ new/jedi-0.19.1/PKG-INFO    2023-10-02 11:19:19.474379500 +0200
@@ -1,6 +1,6 @@
 Metadata-Version: 2.1
 Name: jedi
-Version: 0.19.0
+Version: 0.19.1
 Summary: An autocompletion tool for Python that can be used for text editors.
 Home-page: https://github.com/davidhalter/jedi
 Author: David Halter
@@ -8,6 +8,7 @@
 Maintainer: David Halter
 Maintainer-email: davidhalte...@gmail.com
 License: MIT
+Project-URL: Documentation, https://jedi.readthedocs.io/en/latest/
 Description: 
####################################################################################
         Jedi - an awesome autocompletion, static analysis and refactoring 
library for Python
         
####################################################################################
@@ -235,6 +236,11 @@
         Unreleased
         ++++++++++
         
+        0.19.1 (2023-10-02)
+        +++++++++++++++++++
+        
+        - Python 3.12 support (Thanks Peter!)
+        
         0.19.0 (2023-07-29)
         +++++++++++++++++++
         
@@ -565,6 +571,7 @@
 Classifier: Programming Language :: Python :: 3.9
 Classifier: Programming Language :: Python :: 3.10
 Classifier: Programming Language :: Python :: 3.11
+Classifier: Programming Language :: Python :: 3.12
 Classifier: Topic :: Software Development :: Libraries :: Python Modules
 Classifier: Topic :: Text Editors :: Integrated Development Environments (IDE)
 Classifier: Topic :: Utilities
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/jedi/__init__.py 
new/jedi-0.19.1/jedi/__init__.py
--- old/jedi-0.19.0/jedi/__init__.py    2023-07-29 00:59:28.000000000 +0200
+++ new/jedi-0.19.1/jedi/__init__.py    2023-10-02 11:17:54.000000000 +0200
@@ -27,7 +27,7 @@
 load
 """
 
-__version__ = '0.19.0'
+__version__ = '0.19.1'
 
 from jedi.api import Script, Interpreter, set_debug_function, preload_module
 from jedi import settings
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/test/test_api/test_classes.py 
new/jedi-0.19.1/test/test_api/test_classes.py
--- old/jedi-0.19.0/test/test_api/test_classes.py       2023-07-29 
00:59:28.000000000 +0200
+++ new/jedi-0.19.1/test/test_api/test_classes.py       2023-10-02 
11:17:54.000000000 +0200
@@ -188,10 +188,7 @@
                 assert c.get_signatures()
 
 
-def test_hashlib_params(Script, environment):
-    if environment.version_info < (3,):
-        pytest.skip()
-
+def test_hashlib_params(Script):
     script = Script('from hashlib import sha256')
     c, = script.complete()
     sig, = c.get_signatures()
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/test/test_inference/test_compiled.py 
new/jedi-0.19.1/test/test_inference/test_compiled.py
--- old/jedi-0.19.0/test/test_inference/test_compiled.py        2023-07-29 
00:59:28.000000000 +0200
+++ new/jedi-0.19.1/test/test_inference/test_compiled.py        2023-10-02 
11:17:54.000000000 +0200
@@ -1,4 +1,5 @@
 from textwrap import dedent
+import sys
 import math
 from collections import Counter
 from datetime import datetime
@@ -26,7 +27,10 @@
     assert not from_name.py__doc__()  # It's a stub
 
 
-def test_next_docstr(inference_state):
+def test_next_docstr(inference_state, environment):
+    if environment.version_info[:2] != sys.version_info[:2]:
+        pytest.skip()
+
     next_ = compiled.builtin_from_name(inference_state, 'next')
     assert next_.tree_node is not None
     assert next_.py__doc__() == ''  # It's a stub
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/test/test_inference/test_fstring.py 
new/jedi-0.19.1/test/test_inference/test_fstring.py
--- old/jedi-0.19.0/test/test_inference/test_fstring.py 2023-07-29 
00:59:28.000000000 +0200
+++ new/jedi-0.19.1/test/test_inference/test_fstring.py 2023-10-02 
11:17:54.000000000 +0200
@@ -1,13 +1,6 @@
-import pytest
 from textwrap import dedent
 
 
-@pytest.fixture(autouse=True)
-def skip_not_supported(environment):
-    if environment.version_info < (3, 6):
-        pytest.skip()
-
-
 def test_fstring_multiline(Script):
     code = dedent("""\
         '' f'''s{
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/test/test_inference/test_literals.py 
new/jedi-0.19.1/test/test_inference/test_literals.py
--- old/jedi-0.19.0/test/test_inference/test_literals.py        2023-07-29 
00:59:28.000000000 +0200
+++ new/jedi-0.19.1/test/test_inference/test_literals.py        2023-10-02 
11:17:54.000000000 +0200
@@ -12,29 +12,23 @@
         return def_._name._value.get_safe_value()
 
 
-def test_f_strings(Script, environment):
+def test_f_strings(Script):
     """
     f literals are not really supported in Jedi. They just get ignored and an
     empty string is returned.
     """
-    if environment.version_info < (3, 6):
-        pytest.skip()
-
     assert _infer_literal(Script, 'f"asdf"', is_fstring=True) == ''
     assert _infer_literal(Script, 'f"{asdf} "', is_fstring=True) == ''
     assert _infer_literal(Script, 'F"{asdf} "', is_fstring=True) == ''
     assert _infer_literal(Script, 'rF"{asdf} "', is_fstring=True) == ''
 
 
-def test_rb_strings(Script, environment):
+def test_rb_strings(Script):
     assert _infer_literal(Script, 'x = br"asdf"; x') == b'asdf'
     assert _infer_literal(Script, 'x = rb"asdf"; x') == b'asdf'
 
 
-def test_thousand_separators(Script, environment):
-    if environment.version_info < (3, 6):
-        pytest.skip()
-
+def test_thousand_separators(Script):
     assert _infer_literal(Script, '1_2_3') == 123
     assert _infer_literal(Script, '123_456_789') == 123456789
     assert _infer_literal(Script, '0x3_4') == 52
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/test/test_inference/test_signature.py 
new/jedi-0.19.1/test/test_inference/test_signature.py
--- old/jedi-0.19.0/test/test_inference/test_signature.py       2023-07-29 
00:59:28.000000000 +0200
+++ new/jedi-0.19.1/test/test_inference/test_signature.py       2023-10-02 
11:17:54.000000000 +0200
@@ -13,18 +13,15 @@
     'code, sig, names, op, version', [
         ('import math; math.cos', 'cos(x, /)', ['x'], ge, (3, 6)),
 
-        ('next', 'next(iterator, default=None, /)', ['iterator', 'default'], 
ge, (3, 6)),
+        ('next', 'next(iterator, default=None, /)', ['iterator', 'default'], 
lt, (3, 12)),
+        ('next', 'next()', [], ge, (3, 12)),
 
         ('str', "str(object='', /) -> str", ['object'], ge, (3, 6)),
 
-        ('pow', 'pow(x, y, z=None, /) -> number', ['x', 'y', 'z'], lt, (3, 6)),
         ('pow', 'pow(base, exp, mod=None)', ['base', 'exp', 'mod'], ge, (3, 
8)),
 
-        ('bytes.partition', 'partition(self, sep, /) -> (head, sep, tail)',
-         ['self', 'sep'], lt, (3, 6)),
         ('bytes.partition', 'partition(self, sep, /)', ['self', 'sep'], ge, 
(3, 6)),
 
-        ('bytes().partition', 'partition(sep, /) -> (head, sep, tail)', 
['sep'], lt, (3, 6)),
         ('bytes().partition', 'partition(sep, /)', ['sep'], ge, (3, 6)),
     ]
 )
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/test/test_utils.py 
new/jedi-0.19.1/test/test_utils.py
--- old/jedi-0.19.0/test/test_utils.py  2023-07-29 00:59:28.000000000 +0200
+++ new/jedi-0.19.1/test/test_utils.py  2023-10-02 11:17:54.000000000 +0200
@@ -81,10 +81,10 @@
             if all(not x.startswith('from os import ' + s)
                    for s in ['_', 'O_', 'EX_', 'MFD_', 'SF_', 'ST_',
                              'CLD_', 'POSIX_SPAWN_', 'P_', 'RWF_',
-                             'SCHED_'])
+                             'CLONE_', 'SCHED_'])
         }
         # There are quite a few differences, because both Windows and Linux
-        # (posix and nt) librariesare included.
+        # (posix and nt) libraries are included.
         assert len(difference) < 30
 
     def test_local_import(self):

Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/jedi/api/environment.py 
new/jedi-0.19.1/jedi/api/environment.py
--- old/jedi-0.19.0/jedi/api/environment.py     2023-07-29 00:59:28.000000000 
+0200
+++ new/jedi-0.19.1/jedi/api/environment.py     2023-10-02 11:17:54.000000000 
+0200
@@ -17,7 +17,7 @@
 
 _VersionInfo = namedtuple('VersionInfo', 'major minor micro')  # type: 
ignore[name-match]
 
-_SUPPORTED_PYTHONS = ['3.11', '3.10', '3.9', '3.8', '3.7', '3.6']
+_SUPPORTED_PYTHONS = ['3.12', '3.11', '3.10', '3.9', '3.8', '3.7', '3.6']
 _SAFE_PATHS = ['/usr/bin', '/usr/local/bin']
 _CONDA_VAR = 'CONDA_PREFIX'
 _CURRENT_VERSION = '%s.%s' % (sys.version_info.major, sys.version_info.minor)
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/jedi/inference/__init__.py 
new/jedi-0.19.1/jedi/inference/__init__.py
--- old/jedi-0.19.0/jedi/inference/__init__.py  2023-07-29 00:59:28.000000000 
+0200
+++ new/jedi-0.19.1/jedi/inference/__init__.py  2023-10-02 11:17:54.000000000 
+0200
@@ -90,7 +90,7 @@
         self.compiled_subprocess = 
environment.get_inference_state_subprocess(self)
         self.grammar = environment.get_grammar()
 
-        self.latest_grammar = parso.load_grammar(version='3.11')
+        self.latest_grammar = parso.load_grammar(version='3.12')
         self.memoize_cache = {}  # for memoize decorators
         self.module_cache = imports.ModuleCache()  # does the job of 
`sys.modules`.
         self.stub_module_cache = {}  # Dict[Tuple[str, ...], 
Optional[ModuleValue]]
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/jedi.egg-info/PKG-INFO 
new/jedi-0.19.1/jedi.egg-info/PKG-INFO
--- old/jedi-0.19.0/jedi.egg-info/PKG-INFO      2023-07-29 01:05:44.000000000 
+0200
+++ new/jedi-0.19.1/jedi.egg-info/PKG-INFO      2023-10-02 11:19:19.000000000 
+0200
@@ -1,6 +1,6 @@
 Metadata-Version: 2.1
 Name: jedi
-Version: 0.19.0
+Version: 0.19.1
 Summary: An autocompletion tool for Python that can be used for text editors.
 Home-page: https://github.com/davidhalter/jedi
 Author: David Halter
@@ -8,6 +8,7 @@
 Maintainer: David Halter
 Maintainer-email: davidhalte...@gmail.com
 License: MIT
+Project-URL: Documentation, https://jedi.readthedocs.io/en/latest/
 Description: 
####################################################################################
         Jedi - an awesome autocompletion, static analysis and refactoring 
library for Python
         
####################################################################################
@@ -235,6 +236,11 @@
         Unreleased
         ++++++++++
         
+        0.19.1 (2023-10-02)
+        +++++++++++++++++++
+        
+        - Python 3.12 support (Thanks Peter!)
+        
         0.19.0 (2023-07-29)
         +++++++++++++++++++
         
@@ -565,6 +571,7 @@
 Classifier: Programming Language :: Python :: 3.9
 Classifier: Programming Language :: Python :: 3.10
 Classifier: Programming Language :: Python :: 3.11
+Classifier: Programming Language :: Python :: 3.12
 Classifier: Topic :: Software Development :: Libraries :: Python Modules
 Classifier: Topic :: Text Editors :: Integrated Development Environments (IDE)
 Classifier: Topic :: Utilities
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/jedi.egg-info/requires.txt 
new/jedi-0.19.1/jedi.egg-info/requires.txt
--- old/jedi-0.19.0/jedi.egg-info/requires.txt  2023-07-29 01:05:44.000000000 
+0200
+++ new/jedi-0.19.1/jedi.egg-info/requires.txt  2023-10-02 11:19:19.000000000 
+0200
@@ -33,7 +33,7 @@
 types-setuptools==67.2.0.1
 
 [testing]
-Django<3.1
+Django
 attrs
 colorama
 docopt
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/jedi-0.19.0/setup.py new/jedi-0.19.1/setup.py
--- old/jedi-0.19.0/setup.py    2023-07-29 00:59:28.000000000 +0200
+++ new/jedi-0.19.1/setup.py    2023-10-02 11:17:54.000000000 +0200
@@ -27,12 +27,15 @@
       maintainer=__AUTHOR__,
       maintainer_email=__AUTHOR_EMAIL__,
       url='https://github.com/davidhalter/jedi',
+      project_urls={
+          "Documentation": 'https://jedi.readthedocs.io/en/latest/',
+      },
       license='MIT',
       keywords='python completion refactoring vim',
       long_description=readme,
       packages=find_packages(exclude=['test', 'test.*']),
       python_requires='>=3.6',
       # Python 3.11 grammar is added to parso in 0.8.3
       install_requires=['parso>=0.8.3,<0.9.0'],
       extras_require={
           'testing': [
@@ -41,7 +44,7 @@
               'docopt',
               # coloroma for colored debug output
               'colorama',
-              'Django<3.1',  # For now pin this.
+              'Django',
               'attrs',
           ],
           'qa': [
@@ -97,6 +100,7 @@
           'Programming Language :: Python :: 3.9',
           'Programming Language :: Python :: 3.10',
           'Programming Language :: Python :: 3.11',
+          'Programming Language :: Python :: 3.12',
           'Topic :: Software Development :: Libraries :: Python Modules',
           'Topic :: Text Editors :: Integrated Development Environments (IDE)',
           'Topic :: Utilities',
@@ -27,12 +27,15 @@
       packages=find_packages(exclude=['test', 'test.*']),
       python_requires='>=3.6',
-      # Python 3.11 grammar is added to parso in 0.8.3
+      # Python 3.11 & 3.12 grammars are added to parso in 0.8.3
       install_requires=['parso>=0.8.3,<0.9.0'],
       extras_require={